# -*- coding: utf-8 -*-

import sys
from rhmsg.cli.envs import broker_envs


def disable_argument_debug(debug):
    if not debug:
        return
    sys.stderr.write(
        "Warning: -d or --debug is deprecated and will be removed in next version.\n"
        "To enable logging on AMQP protocol frames, "
        "please set environment variable PN_TRACE_FRM to 1.\n"
        "For more information about logging, please refer to:\n"
        "https://qpid.apache.org/releases/qpid-proton-master/proton/c/api/logging.html\n"
    )
    sys.exit(1)


def add_common_cli_args(parser):
    parser.add_argument(
        "-e",
        "--env",
        choices=list(broker_envs.keys()),
        default="dev",
        help="Environment to connect to. Valid choices: {0} "
        "(default: %(default)s)".format(", ".join(broker_envs.keys())),
    )
    parser.add_argument(
        "-d",
        "--debug",
        dest="debug",
        action="store_true",
        help="The debug mode. More information will be logged into console "
        "from application and underlying library like qpid.proton.",
    )
    parser.add_argument(
        "--certificate-file",
        dest="cert_file",
        help="Absolute or relative path to a certificate file. Used if "
        "connection must be authenticated via SSL.",
    )
    parser.add_argument(
        "--private-key-file",
        dest="private_key_file",
        help="Absolute or relative path to a private Key file. Used together "
        "with argument --certificate-file.",
    )
    parser.add_argument(
        "--ca-certs",
        dest="ca_certs",
        default="/etc/pki/tls/certs/ca-bundle.crt",
        help="Trusted CA certificate bundle (default: %(default)s)",
    )
